import Layout from './layout'
import Row from './row'
import Col from './col'
import Container from './container'
import Header from './header'
import Main from './main'
import Aside from './aside'
import Icon from './icon'
import Link from './link'
import Radio from './radio'
import RadioButton from './radio-button'
import RadioGroup from './radio-group'
import Checkbox from './checkbox'
import CheckboxButton from './checkbox-button'
import CheckboxGroup from './checkbox-group'
import Form from './form'
import FormItem from './form-item'
import FormContent from './form-content'
import Button from './button'
import ButtonGroup from './button-group'
import Table from './table'
import Input from './input'
import InputNumber from './input-number'
import Select from './select'
import Option from './option'
import Cascader from './cascader'
import CascaderPanel from './cascader-panel'
import Switch from './switch'
import Slider from './slider'
import TimeSelect from './time-select'
import TimePicker from './time-picker'
import DatePicker from './date-picker'
import Upload from './upload'
import Rate from './rate'
import ColorPicker from './color-picker'
import Transfer from './transfer'
import TableColumn from './table-column'
import Tag from './tag'
import Progress from './progress'
import Tree from './tree'
import Pagination from './pagination'
import Badge from './badge'
import Avatar from './avatar'
import Skeleton from './skeleton'
import Empty from './empty'
import Descriptions from './descriptions'
import DescriptionsItem from './descriptions-item'
import Result from './result'
import Statistic from './statistic'
import Alert from './alert'
import Loading from './loading'
import Message from './message'
import MessageBox from './message-box'
import Notification from './notification'
import Menu from './menu'
import MenuItem from './menu-item'
import Submenu from './submenu'
import MenuItemGroup from './menu-item-group'
import Tabs from './tabs'
import TabPane from './tab-pane'
import Breadcrumb from './breadcrumb'
import BreadcrumbItem from './breadcrumb-item'
import PageHeader from './page-header'
import Dropdown from './dropdown'
import DropdownMenu from './dropdown-menu'
import DropdownItem from './dropdown-item'
import Steps from './steps'
import Step from './step'
import Dialog from './dialog'
import Tooltip from './tooltip'
import Popover from './popover'
import Popconfirm from './popconfirm'
import Card from './card'
import Carousel from './carousel'
import CarouselItem from './carousel-item'
import Collapse from './collapse'
import CollapseItem from './collapse-item'
import Timeline from './timeline'
import TimelineItem from './timeline-item'
import Divider from './divider'
import Calendar from './calendar'
import Image from './image'
import Backtop from './backtop'
import InfiniteScroll from './infinite-scroll'
import Drawer from './drawer'
import DictSelect from './dict-select'


const components = [
    Layout,
    Col,
    Row,
    Container,
    Header,
    Main,
    Aside,
    Link,
    Radio,
    RadioButton,
    RadioGroup,
    Checkbox,
    CheckboxButton,
    CheckboxGroup,
    Form,
    FormItem,
    FormContent,
    Button,
    ButtonGroup,
    Table,
    Input,
    InputNumber,
    Select,
    Option,
    Cascader,
    CascaderPanel,
    Switch,
    Slider,
    TimeSelect,
    TimePicker,
    DatePicker,
    Upload,
    Rate,
    ColorPicker,
    Transfer,
    TableColumn,
    Tag,
    Progress,
    Tree,
    Pagination,
    Badge,
    Avatar,
    Skeleton,
    Empty,
    Descriptions,
    DescriptionsItem,
    Result,
    Statistic,
    Alert,
    Menu,
    MenuItem,
    Submenu,
    MenuItemGroup,
    Tabs,
    TabPane,
    Breadcrumb,
    BreadcrumbItem,
    PageHeader,
    Dropdown,
    DropdownMenu,
    DropdownItem,
    Steps,
    Step,
    Dialog,
    Tooltip,
    Popover,
    Popconfirm,
    Card,
    Carousel,
    CarouselItem,
    Collapse,
    CollapseItem,
    Timeline,
    TimelineItem,
    Divider,
    Calendar,
    Image,
    Backtop,
    Drawer,
    DictSelect,
    Icon
]

function install(Vue, options = {}) {

    // locale.use(options.locale);
    // locale.i18n(options.i18n);

    components.forEach(component => {
        Vue.component(component.name, component);
    });

    Vue.use(InfiniteScroll);
    Vue.use(Loading.directive);

    // 分页全局配置
    let pagination = options.pagination || {}

    let paginationOptions = {
        layout: pagination.layout || 'prev, pager, next, sizes, jumper',
        pageSizes: pagination.pageSizes || [10, 20, 50, 100]
    }
    // 表单全局配置
    let form = options.form || {}
    let formOptions = {
        placeholder: form.placeholder,
        position: form.position || true
    }
    // 二次封装下拉选择框配置
    let dictSelect = options.dictSelect || {}

    let drawer = options.drawer || {}
    let table = options.table || {}

    Vue.prototype.$ELEMENT = {
        size: options.size || '',
        zIndex: options.zIndex || 2000,
        dictSelect: dictSelect,
        form: formOptions,
        pagination: {
            background: true,
            ...paginationOptions
        },
        drawer: {
            footer: true,
            showCancelButton: true,
            showConfirmButton: true,
            ...drawer
        },
        table: {
            index: true,
            scroll: true,
            ...table
        }
    };

    Vue.prototype.$loading = Loading.service;
    Vue.prototype.$msgbox = MessageBox;
    Vue.prototype.$alert = MessageBox.alert;
    Vue.prototype.$confirm = MessageBox.confirm;
    Vue.prototype.$prompt = MessageBox.prompt;
    Vue.prototype.$notify = Notification;
    Vue.prototype.$message = Message;

}

export default {
    install,
    Layout,
    Row,
    Col,
    Container,
    Header,
    Main,
    Aside,
    Link,
    Icon,
    Radio,
    RadioButton,
    RadioGroup,
    Checkbox,
    CheckboxButton,
    CheckboxGroup,
    Form,
    FormItem,
    FormContent,
    Button,
    ButtonGroup,
    Table,
    Input,
    InputNumber,
    Select,
    Option,
    Cascader,
    CascaderPanel,
    Switch,
    Slider,
    TimeSelect,
    TimePicker,
    DatePicker,
    Upload,
    Rate,
    ColorPicker,
    Transfer,
    Tag,
    Progress,
    Tree,
    Pagination,
    Badge,
    Avatar,
    Skeleton,
    Empty,
    Descriptions,
    DescriptionsItem,
    Result,
    Statistic,
    Alert,
    Loading,
    Message,
    MessageBox,
    Notification,
    Menu,
    MenuItem,
    Submenu,
    MenuItemGroup,
    Tabs,
    TabPane,
    Breadcrumb,
    BreadcrumbItem,
    PageHeader,
    Dropdown,
    DropdownMenu,
    DropdownItem,
    Steps,
    Step,
    Dialog,
    Tooltip,
    Popover,
    Popconfirm,
    Card,
    Carousel,
    CarouselItem,
    Collapse,
    CollapseItem,
    Timeline,
    TimelineItem,
    Divider,
    Calendar,
    Image,
    Backtop,
    InfiniteScroll,
    Drawer,
    DictSelect
}
